#
# spec file for package xkeyboard-config
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xkeyboard-config
Version:        2.42
Release:        3.1
Summary:        The X Keyboard Extension
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND MIT
Group:          System/X11/Utilities
URL:            https://www.freedesktop.org/Software/XKeyboardConfig
Source:         https://xorg.freedesktop.org/archive/individual/data/%{name}/%{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE disable-2xalt_2xctrl-toggle.diff fdo#4927 -- This is just a workaround until fdo#4927 is fixed
Patch109:       n_disable-2xalt_2xctrl-toggle.diff
Patch110:       n_fi-kotoistus-metainfo.patch
%if 0%{?suse_version} < 1550
Patch0:         python-3.11.patch
%endif
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  meson
BuildRequires:  pkgconfig
%if 0%{?suse_version} < 1550
BuildRequires:  python311-base
%else
BuildRequires:  python3-base
%endif
BuildRequires:  xsltproc
BuildRequires:  perl(XML::Parser)
BuildRequires:  pkgconfig(xorg-macros) >= 1.12
Requires(post): coreutils
BuildArch:      noarch

%description
The X Keyboard Extension essentially replaces the core protocol
definition of keyboard. The extension makes possible to clearly and
explicitly specify most aspects of keyboard behaviour on per-key basis
and to more closely track the logical and physical state of the
keyboard. It also includes a number of keyboard controls designed to
make keyboards more accessible to people with physical impairments.

%lang_package

%prep
%autosetup -p1

%build
%{meson} \
    -Dxkb-base=%{_datadir}/X11/xkb \
    -Dcompat-rules=true \
    -Dxorg-rules-symlinks=true
%{meson_build}

%install
%{meson_install}
mkdir -p %{buildroot}%{_localstatedir}/lib/xkb
# Bug 335553
mkdir -p %{buildroot}%{_localstatedir}/lib/xkb/compiled/
ln -snf %{_localstatedir}/lib/xkb/compiled/ %{buildroot}%{_datadir}/X11/xkb/compiled
%find_lang %{name}
%fdupes -s %{buildroot}%{_datadir}/X11/xkb

%post
rm -rf %{_localstatedir}/lib/xkb/compiled/server*.xkm

%files
%license COPYING
%doc AUTHORS README docs/HOWTO.* docs/README.*
%dir %{_localstatedir}/lib/xkb
%dir %{_localstatedir}/lib/xkb/compiled
%dir %{_datadir}/X11
%{_datadir}/X11/xkb/
%{_datadir}/pkgconfig/*.pc
%{_mandir}/man7/*

%files lang -f %{name}.lang

%changelog
* Mon Dec  9 2024 Stefan Dirsch <sndirsch@suse.com>
- python-3.11.patch/buildrequire python311-base
  * fixes build on Leap 15.6 and sle15-sp7
* Mon Oct 28 2024 Stefan Dirsch <sndirsch@suse.com>
- n_fi-kotoistus-metainfo.patch
  * add meta information for default variant of "fi" keyboard layout
    "kotoistus" needed for GNOME or other users of xkeyboard meta XML
    files (boo#1227420)
* Sat Jun  8 2024 Dirk Müller <dmueller@suse.com>
- update to 2.42:
  * Translations updated
* Sun Mar 17 2024 Dirk Müller <dmueller@suse.com>
- update to 2.41:
  * Translations updated
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Wed Nov 22 2023 Stefan Dirsch <sndirsch@suse.com>
- the current source supersedes old sle15-sp5 patches (see
  changelog below)
  * U_Map-evdev-keycodes-KEY_RFKILL-and-KEY_WWAN-to-XF86RF.patch
  * U_Updating-Old-Hungarian.patch
  * U_Fix-media-keys-lag-on-ABNT2-keyboard.patch
  * U_Add-the-new-AZERTY-layout-norm-NF-Z71-300.patch
* Tue Nov 21 2023 Stefan Dirsch <sndirsch@suse.com>
- includes fixes for
  * missing mappings for evdev keys KEY_RFKILL and KEY_WWAN
    (boo#1123784)
  * capslock in Old Hungarian layout (boo#1153774)
  * wrong keyboard mapping causing input delays with ABNT2 keyboards
    (bsc#1191242)
- includes backport of French standardized AZERTY layout (AFNOR:
  NF Z71-300) (bsc#1188867)
* Tue Nov 21 2023 Stefan Dirsch <sndirsch@suse.com>
- supersedes a patch called 'U_fixed-keycode-comment.patch' from
  sle15-sp5, which wasn't applied there any longer either.
    <I247> = 247;   // #define KEY_UWB                 239
  is defined in keycodes/evdev since a long time ...
* Mon Oct  9 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.40
  * mostly updated translation
  * a few bugfixes
* Mon Jun 12 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.39
  * another bugfix release; also needed for changes for the Amharic
    (am_ET.UTF-8) compose key sequences in libX11 1.8.5 (see
    corresponding changelog entry in libX11 package); removes old
    remappings like ar --> ara (git db45bd75, 470ad2cd) [breaks
    current qemu build]
* Thu Apr 20 2023 Stefan Dirsch <sndirsch@suse.com>
- remove CCDL from license strings (boo#1210681)
* Mon Feb  6 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.38
  * Add Russian layout with typographic symbols
  * Update symbols/ru
  * symbols/us: uncomment the nine keys in the international Dvorak layout
  * symbols/bg: reduce the "enhanced" layout to an include + three overrides
  * symbols/epo: reshuffle a comment, and drop unneeded key types
  * replace some Unicode codes with their corresponding symbol name
  * symbols/no: add missing symbols to Sami layout, and remove duplicates
  * symbols/no: add non-dead grave and such to Sami layout, and reshuffle
  * Add apple:jp_oadg109a and apple:jp_pc106 variants
  * Added Gujarati KaGaPa layout (guj-kagapa)
  * Update base.xml
  * rules: add option 'swap_ralt_rctl'
  * prerelease push, for translations
  * Handy script for publishing
  * Making ru(typo) more consistent with existing variants
  * Prerelease translation sync
  * fix rx-51 third level modifier
  * Add Latvia Modern Cyrillic keyboard layout
  * add colemak_dh_ortho
  * Add `trademark` to level4 of us-intl layout
  * dv-intl: add placeholder chars to lvl3+, bind LSGT
* Tue Oct  4 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.37
  * bugfixes
- supersedes U_Fixes-regression-from-c3c5d02-were-mistakenly-replac.patch
* Mon Oct  3 2022 Callum Farmer <gmbr3@opensuse.org>
- Reduce python3 to python3-base
* Thu Jun  2 2022 Stefan Dirsch <sndirsch@suse.com>
- U_Fixes-regression-from-c3c5d02-were-mistakenly-replac.patch
  * Regression fixed from
    c3c5d02rules: sort the names of multimedia keyboards alphabetically
    "\" at the end of line were mistakenly replacd by "/"
* Thu Jun  2 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.36
  * bugfixes
  * removed autotools support :-(
- switched to meson
* Fri Feb 18 2022 Stefan Dirsch <sndirsch@suse.com>
- removed n_suse-ctrl-alt-bksp-terminate.patch
  * no longer needed; made it impossible to disable Ctrl-Alt-BS
    on Wayland (boo#1195871)
* Mon Oct  4 2021 Stefan Dirsch <sndirsch@suse.com>
- update to version 2.34
  * xml2lst: use dynamic Perl path
  * Resolved 101key Old Hungarian II
  * Old turkish f layout (with pc104 support) added.
  * Fix wrong key symbol name
  * Added International Phonetic Alphabet (QWERTY)
  * gitlab CI: update to latest ci-templates
  * Hellenic keyboard perfected.
  * lt: Place sterling symbol on AD03, layer 4 (with E and euro)
  * Use single guillemots on L4 (not less/greater) where L3 has guillemots
  * Added English (Dvorak, Macintosh) based on the MacOS dvorak layout
  * Accommodate uppercase/lowercase ß, long s, §; deduplicate Ł
  * Move left/right quotes one key to the right, place lower quotes on AB04
  * Update symbols/it adding credits and reference for fur lang
  * lt/us: Inherit AE09/AE10 from latin
  * Add Russian GOST layouts
  * Add Polish(lefty) layout
  * Add Arabic(Ergoarabic) keyboard layout
  * translation sync
  * Hebrew translation added
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Jul 17 2021 Dirk Müller <dmueller@suse.com>
- update to version 2.33
  * translation updates
  * Replaced division slash with fraction slash on Neo2 (de) layout
  * rules: correct Indic IPA to use iso639 code "eng"
  * rules: remove two non-existing ISO639 codes
  * rules: change ISO639 language codes to 639-2/T only
  * rules: the xkb.dtd file is not an XML document
  * symbols/nl: Add a "Dutch (US)" variant
  * Simplify gb(basic) so that Shift+Right Alt behaves the same as Right Alt+Shift.
* Tue Feb 16 2021 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.32
  * latest bugfix release
* Wed Oct  7 2020 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.31
  * latest bugfix release
- supersedes U_Fix-symbols-in-syntax-error-spurious-git-conflict-ma.patch
- adjusted n_suse-ctrl-alt-bksp-terminate.patch
* Fri Jul 24 2020 Stefan Dirsch <sndirsch@suse.com>
- U_Fix-symbols-in-syntax-error-spurious-git-conflict-ma.patch
  * Fix symbols/in syntax error: spurious git conflict marker
    (boo#1174483)
* Wed Jun  3 2020 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.30
  * bugfix release
* Thu Apr 23 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 2.29
* Fri Jan 31 2020 Bjørn Lie <bjorn.lie@gmail.com>
- No longer recommend -lang: supplements are in use.
* Fri Oct 11 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.27
  * bugfix release
- supersedes U_Fix-typo-in-Polish-symbols-file.patch
- adjusted n_disable-2xalt_2xctrl-toggle.diff
* Fri Feb  2 2018 sndirsch@suse.com
- U_Fix-typo-in-Polish-symbols-file.patch
  * fixes broken polish symbols file (fdo#104904)
* Thu Feb  1 2018 sndirsch@suse.com
- Update to version 2.23.1
  * Fixing the build
* Wed Jan 31 2018 sndirsch@suse.com
- Update to version 2.23
  * Added it(intl), it(scn) and us(scn)
  * Minor fidvorak adjustment
  * Typo fixed
  * Refreshed the default Arabic keyboard layout
  * more robust comment handling
  * replace 'ʼ' (0x10002bc) with '՚' (0x100055a) in armenian layout
  * Add polish layout for use glagolica script
  * Use default compose key with Finnish keyboard
  * incomplete Finnish fix patch
  * Prerelease translation sync
  * Added International Phonetic Alphabet
- supersedes U_xkeyboard-config_fix-typo-hungarian.patch
* Mon Nov 20 2017 zaitor@opensuse.org
- Add U_xkeyboard-config_fix-typo-hungarian.patch: Fix typo in
  hungarian (fdo#103123).
* Tue Oct 10 2017 sndirsch@suse.com
- n_suse-ctrl-alt-bksp-terminate.patch
  * removed the hunk, which made Shift-RCTL and Shift-RALT the
    default Compose key (bsc#1059438)
* Thu Oct  5 2017 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.22:
  + typofix tel-sarala key layout
  + Whitelist Indian keyboard layouts. #101532
  + Enable level3 ralt_switch by default in Kazakh (ext) layout.
  + Extend more keys in Kazakh (ext) layout.
  + Add "AltGr" back into the description for altgr-intl layouts
  + Added Old Hungarian layout
  + ctrl: add missing modifier_map
  + Add grp:menu_switch
  + adds the shortDescription for es-cat and es-ast layouts
  + Added Friulian translation
  + Missing fur in ALL_LINGUAS added
  + Add a Arabic version of Jawi keyboard layout and it's own phonetic version
  + Adding Finnish Dvorak layout
  + Add Ladin layout for it and de keyboards
  + Double Russian fixed
  + Possible typo in word "lever"
  + Typo for Dell latitude
  + Choose only one between "behavior" and "behaviour"
  + Typo in "non-breakable space"
  + Spelling fix in guillemets
  + Add Swedish sv_dvorak based on us dvorak-intl
  + fixed nontranslatable description and shortDescription tags
  + Prerelease translations sync
  + Added a bit of explanation for diff, to make it clear
  + Fixed old Hungarian
  + Replaced NoSymbol with dead_belowmacron in default German keyboard layout
  + Added Polyglot and Reactionary Russian layout
* Fri Jun  2 2017 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.21:
  + Two "Hausa" layout variants with identical descriptions
  + Fixed RALT config of de(T3)
  + Descriptions formatting, typos and mistakes v2
  + two new layouts "Russian (Germany, recommended)" and "Russian (Germany,
    transliteration)" for german keyboards
  + Updated apl stuff
  + Updated apl version
  + Added it(fur)
  + Updated translations (broken with prev commit)
  + Add missing letter I̵ to French (Togo) keyboard and update language list
  + Duplicate "Malay (Jawi)" entry
  + Update to lk(us)
  + Missing closing bracket on keyboard layout: Slovak (extended backslash),
    Slovak (querty, extended backslash)
  + Amending typo
  + English (Canada) input source is missing the left backslash key
  + UK is not an exception any more
  + Missing closing bracket on keyboard layout: Slovak (extended backslash),
    Slovak (querty, extended backslash)
  + Adding Sarala Telugu Keyboard layout.
  + steelseries apex300 geometry
* Wed Feb  1 2017 sndirsch@suse.com
- Update to version 2.20
  * Bug fixes and performance improvements
* Tue Oct  4 2016 sndirsch@suse.com
- Update to version 2.19
  * Bug fixes and performance improvements
* Wed Jun  8 2016 tchvatal@suse.com
- Run over with spec-cleaner - pkgconfig/perl deps conversion
- Use post dependency on coreutils instead of prereq
- Disable silent rules to see whats happening
- Tweak configure options to match what configure.ac contains and what
  is needed
- Remove path provides on the old /etc location, should not be needed
  after all those years
* Mon Jun  6 2016 sndirsch@suse.com
- Update to version 2.18
  * Add Ctrl+Win keyboard layout switch.
  * rules: Giving the caps:ctrl_modifier option a distinctive description.
  * Sorting the Caps Lock options in a consistent manner.
  * symbols: add explicit definition for Group2 to win_space_toggle
  * Added Bone layout (including the q/eszett variant) and Neo qwertz/qwerty
  * Added the Ruble signe
  * Added us(carpalx)
  * Add Algerian layout with variants
  * Added some Asian layouts
  * Added US layout for IBM Arabic 238L
  * Synced descriptions
  * Added Armenian dram sign to Armenian phonetic
  * Fixed ISO codes for Jawi
* Wed Jan 27 2016 sndirsch@suse.com
- Update to version 2.17
  * Added sbj keymap for Jolla phone
  * Adding the option to make Caps Lock act as a Menu key.
  * add altwin:prtsc_rwin
  * Add br(thinkpad) to the xml files
  * symbols/group: re-enable grp:ctrls_toggle
  * Make us(dvp) work with regular right Alt key again
  * Updated Azerbaijani layout
  * Azerty French Layout
  * Added French Togo
  * More changes to tg layout
  * Added de(koy)
  * syntax fix
  * Translations updated before release
  * Reenable layer5-lock for de variants
  * Icelandic QWERTY Layout: Add ability to write Icelandic quotation marks („“)
* Fri Jan 22 2016 sndirsch@suse.com
- add /usr/share/X11 dir to filelist in order to fix build again
* Mon Dec 28 2015 eich@suse.com
- Adding 'BuildRequires: xsltproc' to build man page.
* Mon Dec 28 2015 eich@suse.com
- Removed link from /usr/share/X11/xkb/xkbcomp to /usr/bin/xkbcomp
- Removed xkbcomp as Buildrequire (bnc#953161)
- Added man page xkeyboard-config (7)
* Tue Oct 20 2015 tobias.johannes.klausmann@mni.thm.de
- Rename n_suse.patch -> n_suse-ctrl-alt-bksp-terminate.patch to
  reflect patch usage
- Rename disable-2xalt_2xctrl-toggle.diff ->
  n_disable-2xalt_2xctrl-toggle.diff to follow X11:XOrg patch
  guidelines
* Tue Oct 20 2015 sndirsch@suse.com
- Update to version 2.16
  * Move apostrophe U+0027 to the first level and add U+02BC one to
    ua(unicode)
  * Add support for chromebooks layout
  * Add missing semicolons in symbols/inet
  * Undo incompatible us(dvp) layout additions
  * Define a keyboard layout for the Ol Chiki script
  * new layout - Russian Phonetic Czech
  * Correct capitalization and naming of us(dvp) "Programmer Dvorak"
  * added swap_lalt_lwin
  * fixed Icelandic Dvorak
  * Broken xml fixed
  * Fixed mac file, use utf-8
  * Added Teck keyboard
  * added missing Teck file
  * prerelease translation sync
  * Added Finnish DAS layout
- refreshed n_suse.patch
* Wed May 27 2015 sndirsch@suse.com
-  Update to version 2.15
  * Here is another minor release. Thanks to the Translation
    Project for the several updated translations.
  - symbols/typo: rework typographic layout.
  - Add support for Latinamerican Dvorak layout
  - added lk(us)
  - fixed the license (removed GPL)
  - Removed GPLv3 line
  - Fixed Singhala -> Sinhala
  - Updated cm layout
  - Updated from TP
  - Update from TP
  - Define <LSGT> key properly in basic layout
* Mon Feb  9 2015 sndirsch@suse.com
- Update to version 2.14
  bug fixes, documentation fixes
* Wed Oct  1 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.13:
  Code cleanup, small changes and translation updates
* Wed Jun  4 2014 sndirsch@suse.com
- Update to version 2.12
  * bugfix release
  * supersedes U_Let-KPDL-key-on-it-fr-and-nl-keyboards-generate-KP_S.patch
- remove n_rs-cyralpha-The-key-z-on-US-keyboard-should-give-dze.patch,
  which is considered wrong (bnc#68754)
* Tue Feb  4 2014 sndirsch@suse.com
- U_Let-KPDL-key-on-it-fr-and-nl-keyboards-generate-KP_S.patch
  * reverse apply the above patch in order to fix again the KPDL
    key on french, italian and netherland keyboards (bnc#671931)
* Thu Jan 30 2014 sndirsch@suse.com
- Update to version 2.11
  + There is traditional massive code cleanup by Benno - and a
    number of other fixes and updated translations (thanks to TP)
* Mon Oct  7 2013 sndirsch@suse.com
- fixed source link in specfile
* Fri Oct  4 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.10.1:
  The release 2.10 of xkeyboard-config did not really happen because of
  the technical issues, so I am happy to present 2.10.1
  + massive cleanups of the codebase.
  + various layouts fixes and code improvements.
- Remove upstreamed patches:
  + Patch11: U_Add-missing-backslash-bar-mapping-on-us-internationa.patch
  + Patch12: U_ara-digits-Generate-arabic-script-digits-also-on-key.patch
- Updated Patch100: n_suse.patch to work with this version.
* Tue Sep 10 2013 sndirsch@suse.com
- renamed U_rs-cyralpha-The-key-z-on-US-keyboard-should-give-dze.patch
  to n_rs-cyralpha-The-key-z-on-US-keyboard-should-give-dze.patch
  since it will never be accepted upstream, but still needed for QA
  people not being aware of the special situation of serbian-cyrillic
  keyboard users (#fdo#68754)
* Wed Sep  4 2013 sndirsch@suse.com
- renamed u_zhe-dze.patch to
  U_rs-cyralpha-The-key-z-on-US-keyboard-should-give-dze.patch
  after having it upstreamed (#fdo#68754)
* Fri Aug 30 2013 sndirsch@suse.com
- renamed p_suse.diff to n_suse.patch (never to be upstreamed)
  according to X11:XOrg patch guidelines
* Fri Aug 30 2013 sndirsch@suse.com
- U_Add-missing-backslash-bar-mapping-on-us-internationa.patch
  * Add missing backslash/bar mapping on "us" international
    variants (fdo#68606, bnc#831823).
- U_ara-digits-Generate-arabic-script-digits-also-on-key.patch
  * ara(digits): Generate arabic script digits also on keypad
    (fdo#68650, bnc#831823)
- refreshed patches
* Tue Aug 27 2013 sndirsch@suse.com
- remove server-*.xkm in %%post to show correct layout after
  package upgrade. (bnc#662014, bnc#831823)
* Wed May 29 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.9:
  + Fix AE00 alias in olpcm keycodes
  + Fix keyboard indicator for russian (germany, phonetic)
  + Add XF86AudioMicMute mappings
  + Add various compose:*-altgr options.
  + rules: fix iso639 code for irish
  + Fixing wrong iso639-3 codes
  + Fixing ISO codes
  + English Mali layouts have English language assigned to them
  + fr --> fra (ISO 639)
  + Fixed ru(ruu) - invalid keysym
  + Updates to Cameroon Keyboard
  + Map Alt to Win
  + Fixed UK Macbook Pro layouts
  + Fixed Congolese
  + Added ru(mac)
  + Added RAlt as 3rd level switcher to us(dvp)
  + Remove explicit virtual modifier setting for level3 and level5
  + add support for the OLPC mechanical non-membrane keyboard
* Tue Mar 26 2013 sndirsch@suse.com
- u_zhe-dze.patch
  The key (z on US keyboard) should give dze (&#1029; [capital]
  / &#1109;) but it gives zhe (&#1046; [capital] / &#1078;)
  (bnc#780230)
* Thu Jan 31 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.8:
  Some commits all over the place, shortlog is here:
  http://lists.x.org/archives/xorg-announce/2013-January/002152.html
* Thu Sep 27 2012 cfarrell@suse.com
- license update: GPL-2.0+ and LGPL-2.1+ and MIT and CDDL-1.0
  Everything below symbols/sun_vndr/ is CDDL-1.0 licensed
* Wed Sep 26 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.7:
  + Several bugs fixed, most notably - the issue with functional
    keys and Shift.
  + Unneeded .dir files are not generated any more.
  + Some translations are updated!
* Sat Jul 21 2012 dimstar@opensuse.org
- Split out -lang package (bnc#645077).
* Tue Jun 26 2012 sndirsch@suse.com
- improved BuildRequires; instead of xorg-x11 meta package require
  xkbcomp package
* Thu Jun 14 2012 seife+obs@b1-systems.com
- don't require xorg-x11 - it's just a compat metapackage nowadays
* Thu Apr 12 2012 vuntz@opensuse.org
- Update to version 2.5.1:
  + Updated translations.
- Changes from version 2.5:
  + Critical security bug fixed: Grabs and screensavers
  + Add option to map Zenkaku_Hankaku to Escape
  + 15 bugs fixed
  + Updated translations.
- Changes from version 2.4.1:
  + Critical bug fixed: many Ctl+Alt combinations broken
- Changes from version 2.4:
  + Add option to use RAlt as RCtrl
  + 9 bugs fixed
  + Updated translations.
- Changes from version 2.3:
  + Serious cleanup of descriptions
  + Updated translations.
- Drop MDSW-change-keycode.diff: fixed upstream.
- Add pkgconfig(xorg-macros) BuildRequires: new dependency
  upstream.
* Mon May 23 2011 eich@suse.de
- remove xkeyboard-config.inet.patch:
  * There is an entry for KP_Equal in inet(apple) already:
    key <KPEQ>  {       [ KP_Equal ] };
    With the macintosh keycodes <KPEQ> has the same value as
    <K59> in the xfree86 keycodes file (i.e. 157).
* Mon May 23 2011 eich@suse.de
- place all SUSE specific patches into one file:
  * add Multi_key for compose.
  * add ctrl-alt-backspace server termination key sequence.
* Mon May 23 2011 eich@suse.de
- remove xkeyboard-config.macintosh.patch:
  This can be handled by adding:
  altwin:swap_lalt_lwin,lv3:alt_switch
  as option for instance to the keyboard mappings for macintosh.
  The xorg-x11 package will be updated accordingly.
* Mon May 23 2011 eich@suse.de
- Remove xkeyboard-config.inet.microsoftpro.patch:
  This patch is bogus and not needed for evedev keyboards any
  more.
  For old style keyboard +inet(microsoftprousb) specified the
  augmentation used for a specific keyboard model. This this
  keyboard model should be set instead ie:
  setxkbmap -rules base -model microsfortprousb -layout <lo> -option ""
  produces the same results as:
  setxkbmap -rules base -model pc104 -layout <lo> -option inet:microsoftpro
  (disregarding the geometry part which is rather irrelevant here).
* Mon May 23 2011 eich@suse.de
- IBM Space Saver keyboard support was added upstream with
  commit b69a8bd.
* Mon May 23 2011 eich@suse.de
- Remove special handling for the microsoftnek4k
  keyboard. This is handled correctly in evdev
  already.
* Thu Apr  7 2011 fcrozat@novell.com
- Update to version 2.2.1:
  + fix build with libX11 1.4.3.
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 2.2:
  + fdo#35642: major change in Burmese layout
* Mon Mar 28 2011 fcrozat@novell.com
- Update to version 2.1.99:
  + Major changes in descriptions: for GNOME3 release
  + Some new layouts and models. Translations are not updated.
  + Checking runtime dependencies at build time
- Rebase microsoftnek4k.diff
- Disable runtime dependencies check at build time, not relevant
  for us.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sat Feb  5 2011 sndirsch@novell.com
- xkeyboard-config 2.1
  * Again, some tweaks and additions, here and there. Updated 12
    translations, thanks to TP.
- refreshed patches
* Wed Sep 29 2010 sndirsch@novell.com
- xkeyboard-config 2.0
  * More layouts, more options. Updated translations.
- adjusted ibm_space_saver.diff
* Sat Sep  4 2010 sndirsch@novell.com
- xkeyboard 1.9
- obsolete patches
  * xkeyboard-config.mainline-cvs.mac-es.patch
  * xkeyboard-config-commit-81d9313.diff
  * xkeyboard-config-commit-dc87d0c.diff
- adjusted patches
  * ibm_space_saver.diff
  * microsoftnek4k.diff
  * p_suse.diff
  * xkeyboard-config.ctrl_alt_bksp.patch
  * xkeyboard-config.inet.microsoftpro.patch
  * xkeyboard-config.macintosh.patch
- make use of %%fdupes macro
- added new pkgconfig file
* Sat Jun 19 2010 sndirsch@suse.de
- xkeyboard-config.ctrl_alt_bksp.patch
  * enable zapping by default (still protected by ZapWarning)
    (bnc #576481)
* Sat May 15 2010 sndirsch@suse.de
- xkeyboard-config-commit-dc87d0c.diff
  * Enhancement to hu keymap (bnc #599318, bfo #28091)
* Thu May  6 2010 sndirsch@suse.de
- xkeyboard-config-commit-81d9313.diff
  * Added several chars to hu layout (bnc #599318, bfo #27825)
- xkeyboard-config.inet.microsoftpro.patch
  * fixed inet:media_common mapping (bnc #602129)
  * changed inet:microsoftpro mapping to inet(microsoftprousb),
    since inet(microsoftpro) no longer exists (bnc #602129)
* Fri Dec  4 2009 sndirsch@suse.de
- remove line accidentally left in during patch adaption to fix
  macbook again (Ruediger Oertel)
* Tue Nov 17 2009 sndirsch@suse.de
- xkeyboard-config 1.7
  * Around 30 bugs from freedesktop.org bugzilla were fixed.
  * Restructured rules-generating scripts.
- obsoletes ucw_suse.diff, xkeyboard-config.sr@latin.diff, cs.po.diff
- adjusted microsoftnek4k.diff, p_suse.diff,
  xkeyboard-config.macintosh.patch,
  xkeyboard-config.inet.microsoftpro.patch
* Mon Apr 27 2009 sndirsch@suse.de
- removed tp-menu.diff
* Mon Apr 27 2009 sndirsch@suse.de
- xkeyboard-config.inet.microsoftpro.patch (bnc #497647)
  * adds microsoftpro internet keyboard keys to any keyboard when
    adding the line: Option "XkbOptions" "inet:microsoftpro" to the
    keybaord input device section of xorg.conf.
  * obsoletes xkeyboard-config.jp.jp106_inet.patch,
    xkeyboard-config.br.abnt2_inet.patch
* Sat Apr 25 2009 sndirsch@suse.de
- xkeyboard-config.jp.jp106_inet.patch
  * new jp106_inet xkbmodel required for jp layout (bnc #497647)
* Sat Apr 25 2009 sndirsch@suse.de
- xkeyboard-config.br.abnt2_inet.patch
  * new abnt2_inet xkbmodel required for br layout (bnc #497647)
* Thu Apr  9 2009 sndirsch@suse.de
- minor cleanup
* Mon Apr  6 2009 eich@suse.de
- Update patches to apply without fuzz to current package.
* Tue Mar  3 2009 sndirsch@suse.de
- xkeyboard-config 1.5
  * More than 40 bugs from freedesktop.org bugzilla were fixed.
    symbols/inet restructured.
- obsoletes xkeyboard-config.powerbook-usb-iso-keyboard.patch,
  unknown-keysym.diff
- adjusted MDSW-change-keycode.diff, xkeyboard-config.inet.patch
  disable-2xalt_2xctrl-toggle.diff, ucw_suse.diff
- cs.po.diff
  * removed dup to fix build
* Mon Feb  9 2009 sndirsch@suse.de
- sr@Latn no longer exists; moved it to sr@latin
* Thu Feb  5 2009 sndirsch@suse.de
- added /usr/share/locale/sr@Latn{,LC_MESSAGES} as directories to
  filelist to fix build for factory
* Mon Sep 15 2008 sndirsch@suse.de
- updated ucw_suse.diff
  * patching rules/compat/layoutRename.lst instead of
    rules/compat/base.l?_s.part (Milan Vancura)
* Mon Sep 15 2008 sndirsch@suse.de
- ucw_suse.diff
  * For a long time (~10 years) UCW keyboard layout is used by
    many Czech people. It is a trivial configuration change not
    affecting anything else (no other dependencies) but a big help
    for many Czech programmers. (Milan Vancura)
* Sun Jul 20 2008 sndirsch@suse.de
- xkeyboard-config 1.3
  * Around 40 bugs from freedesktop.org bugzilla were fixed. Dropped
    old rulesets sgi and sun. Added a lot of metadata, related to
    countries and languages.
- obsoletes lv.diff
* Mon Jul  7 2008 sndirsch@suse.de
- reverted previous patch, which was wrong (bnc #405055)
* Wed Jul  2 2008 sndirsch@suse.de
- cz_sk-dropKPDL.diff
  * drop KPDL from cz/sk keyboard layout (bnc #405055, bfo #14479)
* Fri May 16 2008 sndirsch@suse.de
- unknown-keysym.diff
  * don't map a key to an unknown keysym (bnc #391341)
* Thu May 15 2008 sndirsch@suse.de
- MDSW-change-keycode.diff
  * change keycode for virtual <MDSW> key (bnc #389943)
* Tue May 13 2008 sndirsch@suse.de
- disable-2xalt_2xctrl-toggle.diff
  * disable Ctrl-Ctrl and Alt-Alt toggle (bnc #373197)
* Fri Apr  4 2008 sndirsch@suse.de
- keyboard layout switching is now also possible as root (bnc #335553)
* Mon Mar 10 2008 sndirsch@suse.de
- fixed keycodes of MS nek4k (bnc #366515)
* Mon Mar 10 2008 sndirsch@suse.de
- more work on support for MS nek4k
* Sat Mar  8 2008 sndirsch@suse.de
- added support for 'Microsoft Natural Ergonomic Keyboard 4000'
  (bnc #366515)
* Mon Mar  3 2008 sndirsch@suse.de
- lv.diff
  * fixed accented characters in latvian keyboard layout
    (bnc #366362, bfo #14756)
* Wed Jan 30 2008 sndirsch@suse.de
- xkeyboard-config 1.2
  * Some bugs are fixed (26), new layouts/models as usual. A lot of
    code from OLPC is committed.
    The important change is the new translation schema. Now,
    base.xml does not contain all translations (which made it huge).
    Instead, it contains only English strings.  The .gmo files are
    installed as a part of the installation process. It is up to
    the applications/libs (libxklavier) to invoke gettext functions
    at runtime - using the "xkeyboard-config" domain.
* Sat Sep 29 2007 sndirsch@suse.de
- xkeyboard-config 1.1
  * some bug fixes (27)
  * new layouts/models
* Sat Aug 25 2007 sndirsch@suse.de
- reverted tp-menu.diff (wrong approach, Bug #302099)
* Thu Jul 12 2007 sndirsch@suse.de
- xkeyboard-config 1.0
  * It is about 9 months since 0.9 - and here goes 1.0. There is
    nothing special big and special about that release, it is
    rather "0.9 + 0.1" than "1.0" release. Around 70 bugs from
    freedesktop.org bugzilla were fixed. The largest user-visible
    change is elimination of the word "group" in base.xml - it is
    replaced with "layout". This makes UIs using those strings
    easier to perceive.
- removed obsolete patches
  * xkeyboard-config.mainline-cvs.group.patch
  * xkeyboard-config.mainline-cvs.il.patch
  * xkeyboard-config.mainline-cvs.it.patch
  * xkeyboard-config.mainline-cvs.level3.patch
  * xkeyboard-config.mainline-cvs.mac-euro.patch
  * xkeyboard-config.mainline-cvs.mac-us.patch
  * xkeyboard-config.mainline-cvs.trans.patch
  * xkeyboard-config.mainline-cvs.us-backslash.patch
- adjusted patches
  * p_suse.diff
  * xkeyboard-config.inet.patch
  * xkeyboard-config.macintosh.patch
  * xkeyboard-config.mainline-cvs.mac-es.patch
* Tue May 22 2007 sndirsch@suse.de
- tp-menu.diff:
  * add mapping for Menu key on new Thinkpads like T60 (Bug #253397)
* Mon May 21 2007 sndirsch@suse.de
- xkeyboard-config.mainline-cvs.us-backslash.patch:
  * backslash needs to be explicitely set in us (Bug #275561)
* Sun May 13 2007 sndirsch@suse.de
- xkeyboard-config.mainline-cvs.il.patch:
  * fixed mapping for "|" symbol in hebrew layout (Bug #273712)
* Sat Apr 28 2007 schwab@suse.de
- Fix unknown keysym in inet(cymotionlinux).
- Fix keycode for KP_Equal in inet(apple).
* Sun Apr  8 2007 schwab@suse.de
- Regenerate *.dir files.
- Reduce build requirements.
* Sat Feb  3 2007 sndirsch@suse.de
- removed braindead cz-basic-bksl.diff again (Bugs #215359/#241824);
  use variant bksl/qwerty_bksl for cz keyboard layout instead
* Wed Nov 15 2006 sndirsch@suse.de
- xkeyboard-config.mainline-cvs.trans.patch:
  * updated Hungarian translations (Bug #8996)
* Fri Oct 27 2006 olh@suse.de
- disable apple:badmap/apple:goodmap for Powerbooks with built-in
  USB ISO keyboard. The kernel delivers the correct keys now
* Fri Oct 27 2006 sndirsch@suse.de
- cz-basic-bksl.diff:
  * fixes backslash/bar on czech keyboard (Bug #215359)
* Tue Oct 17 2006 olh@suse.de
- update mac/es, add euro to mac/us and mac/dk
* Tue Oct 17 2006 olh@suse.de
- more fixes from cvs, restore previous macintosh behaviour
* Mon Oct 16 2006 olh@suse.de
- fix symbols on macintosh
* Tue Oct 10 2006 sndirsch@suse.de
- updated to release 0.9:
  * Around 80 bugs from freedesktop.org bugzilla are fixed.
  * New layouts/models/translations are introduced.
  * Macintosh layouts are heavily redesigned (big thangs to Denis
    Barbier).
- adjusted ibm_space_saver.diff, p_suse.diff
- obsoletes ISO_Level5.diff, c300.diff, logitech.diff, ralt.diff,
  xkeyboard-config_korean.diff
- disabled p_macintosh-kb.diff since it no longer applies due to
  radical changes for Macintosh layout (see above); hopefully it's
  no longer required ...
* Tue Aug  1 2006 sndirsch@suse.de
- added xorg-x11 to Requires/BuildRequires to fix build
- cleanup
* Fri Jul 28 2006 sndirsch@suse.de
- use "-fno-strict-aliasing"
* Thu Jul 27 2006 sndirsch@suse.de
- added support for inet keys on Acer C300 Laptop (dsieben)
  (fd.o Bug #7651)
* Tue Jul 25 2006 sndirsch@suse.de
- adjusted for X.Org 7
* Sat Jun 24 2006 sndirsch@suse.de
- logitech.diff:
  * removed double entry for XF86AudioRaiseVolume (Bug #181118)
* Wed Jun 14 2006 sndirsch@suse.de
- use explicit hexadecimal values instead of XK_ISO_Level5 defines;
  makes changes in X.Org unnecessary (Bug #158951, X.Org Bug #4411)
* Sat Jun 10 2006 sndirsch@suse.de
- ISO_Level5.diff:
  * obsoletes ca_multi.diff (Bug #158951, X.Org Bug #4411)
* Fri Jun  9 2006 sndirsch@suse.de
- ca_multi.diff:
  * added support for "Canada - Multilingual" keyboard (Bug #158951)
* Sat Apr 15 2006 sndirsch@suse.de
- updated to release 0.8
  * obsoletes khmer.diff, numlock-scrollLock.diff
* Sat Mar 25 2006 sndirsch@suse.de
- ralt.diff:
  * addresses RAlt problems (Bug #158177, Ubuntu #35845)
* Mon Mar 20 2006 sndirsch@suse.de
- xkeyboard-config_korean.diff:
  * korean keyboard layout (Bug #87443, freedesktop Bug #6323)
* Mon Feb 13 2006 sndirsch@suse.de
- added missing xorg rules symlinks (Bug #150245)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Jan 22 2006 sndirsch@suse.de
- numlock-scrollLock.diff:
  * fix for Numlock/ScrollLock problem (X.Org Bug #5635)
* Mon Jan 16 2006 sndirsch@suse.de
- khmer.diff:
  * adds khmer keyboard support (Bug #143348)
* Wed Jan  4 2006 sndirsch@suse.de
- added xorg.lst compatibility symlink (required by xorgcfg)
* Fri Dec 23 2005 sndirsch@suse.de
- updated to new version 0.7
* Mon Dec  5 2005 sndirsch@suse.de
- updated to current CVS release (2005-12-05)
* Thu Dec  1 2005 sndirsch@suse.de
- updated to current CVS release (2005-12-01)
  * obsoletes br-abnt2.diff
  * fixes Dell Inspiron 6000 layout for special keys (#135764)
  * obsoletes patches for symbols/macintosh_vndr/fr (X.Org #2870)
* Tue Sep 20 2005 sndirsch@suse.de
- br-abnt2.diff:
  * fixed brazilian "abnt2" keyboard layout (#116425)
* Tue Sep  6 2005 sndirsch@suse.de
- removed Prereq to xorg-x11 (#115369)
* Thu Aug 25 2005 sndirsch@suse.de
- updated to new version 0.6
  * move Macedonian to country-based
  * translation updates
* Wed Aug 24 2005 sndirsch@suse.de
- updated to current CVS release (2005-08-24)
  * fr-latin9 compatibility rule added
  * added Thaana Keyboard Map
  * "Major Balkanian revolution" (Danilo Segan)
  * updated russian and turkish translations
* Fri Aug 19 2005 sndirsch@suse.de
- updated to current CVS release (2005-08-20)
  * updated Iranian layout to new standard (fd.o Bug #4102)
  * updated translations for tr
* Wed Aug 17 2005 sndirsch@suse.de
- ibm_space_saver.diff:
  * add support for "ibm_space_saver" keyboards (Bug #59788)
* Sun Aug 14 2005 sndirsch@suse.de
- updated to current CVS release (2005-08-14)
  * obsoletes print-screen.diff
  * buildfix for update-pot/update-po in po/Makefile.am
* Thu Aug 11 2005 sndirsch@suse.de
- print-screen.diff:
  * fixes GNOME print-screen functionality (Bug #103990)
* Wed Aug 10 2005 sndirsch@suse.de
- updated to current CVS release (2005-08-10)
* Tue Aug  2 2005 schwab@suse.de
- Fix reference to eject key in macintosh keymap.
- Make noarch.
* Fri Jul 29 2005 sndirsch@suse.de
- xkeyboard-config-0.5.diff:
  * fixes typo: options --> option (Bug #98980)
- enabled use of xkeyboard-config again
* Thu Jul 28 2005 sndirsch@suse.de
- make xkeyboard-config optional again; currently to big problems
  (Bug #98980)
* Tue Jul 26 2005 sndirsch@suse.de
- finally remove /etc/X11/xkb/symbols/pc directory of xorg-x11
  package (%%pre)
* Thu Jul 14 2005 sndirsch@suse.de
- added /etc/X11/xkb/xkbcomp to package instead of
  creating/removing the symlink in %%post/%%preun
* Mon Jul 11 2005 sndirsch@suse.de
- add "Prereq: xorg-x11" to make sure that /etc/X11/xkb/symbols/pc/
  directory will be removed before xkeyboard-config installs
  /etc/X11/xkb/symbols/pc file (Bug #95914).
* Wed Jul  6 2005 sndirsch@suse.de
- add symlink /usr/X11R6/lib/X11/xkb --> /etc/X11/xkb
* Wed Jul  6 2005 sndirsch@suse.de
- install package during update when xorg-x11/XFree86 package was
  already installed
* Wed Jul  6 2005 sndirsch@suse.de
- use /etc/X11/xkb for data files now; replaces the data files of
  xorg-x11 package
* Fri May 13 2005 sndirsch@suse.de
- use norootforbuild
* Sun Apr 17 2005 sndirsch@suse.de
- enabled compatibity rules (compatibility on 'XkbLayout' level)
* Sun Feb  6 2005 sndirsch@suse.de
- updated to release 0.5:
  * More bugs from freedesktop.org bugzilla fixed.
    The group names now are matching the descriptions - and the
    validating scripts are implemented.
    Some layouts, variants, models are added/fixed.
    Some translations are updated (though the overall translation
    activity is disappointinly low).
  * obsoletes p_xkb-cherryblueb.diff
* Sun Oct 24 2004 sndirsch@suse.de
- updated patches
- removed obsolete patches
* Sun Oct  3 2004 sndirsch@suse.de
- updated to release 0.4:
  * A lot of fixes. More univeral EURO handling. New urdu layout.
    Improved handling for indicators.
* Wed Sep 29 2004 sndirsch@suse.de
- added missing prerequires ln,rm (Bug #46480)
* Sat Jul 24 2004 sndirsch@suse.de
- updated to release 0.3
  * adjusted patches p_XFree86-4.3-kbdmapping.diff,
    p_xkb-cherryblueb.diff
  * adjusted filelist (.mo files no longer exist, added HOWTO.testing)
* Wed Jul 21 2004 sndirsch@suse.de
- added README.SuSE
* Sat Jun 12 2004 sndirsch@suse.de
- added required hunks of X.Org patches for xkb:
  * p_suse.diff
  * p_fixes.diff
  * p_xkb-cherryblueb.diff
  * p_XFree86-4.3-kbdmapping.diff
  * p_macintosh-kb.diff
* Sat Jun 12 2004 sndirsch@suse.de
- created package
